\name{AntiAliasBinaryImageFilter}
\alias{AntiAliasBinaryImageFilter}
\title{AntiAliasBinaryImageFilter}
\Rdversion{1.1}
\docType{class}
\description{
A method for estimation of a surface from a binary volume.
AntiAliasBinaryImageFilter}
\details{
This filter implements a surface-fitting method for estimation of a
surface from a binary volume. This process can be used to reduce
aliasing artifacts which result in visualization of binary partitioned
surfaces.
The binary volume (filter input) is used as a set of constraints in an
iterative relaxation process of an estimated ND surface. The surface
is described implicitly as the zero level set of a volume \eqn{ \phi } and allowed to deform under curvature flow. A set of constraints is
imposed on this movement as follows:
 \deqn{ u_{i,j,k}^{n+1} = \left\{  max (u_{i,j,k}^{n} + \Delta t H_{i,j,k}^{n}, 0) B_{i,j,k} = 1 \\ min (u_{i,j,k}^{n} + \Delta t H_{i,j,k}^{n}, 0) B_{i,j,k} = -1 \right. }
where \eqn{ u_{i,j,k}^{n} } is the value of \eqn{ \phi } at discrete index \eqn{ (i,j,k) } and iteration \eqn{ n } , \eqn{ H } is the gradient magnitude times mean curvature of \eqn{ \phi } , and \eqn{ B } is the binary input volume, with 1 denoting an inside pixel and -1
denoting an outside pixel.
NOTES
This implementation uses a sparse field level set solver instead of
the narrow band implementation described in the reference below, which
may introduce some differences in how fast and how accurately (in
terms of RMS error) the solution converges.
REFERENCES
Whitaker, Ross. "Reducing Aliasing Artifacts In Iso-Surfaces of
Binary Volumes" IEEE Volume Visualization and Graphics Symposium,
October 2000, pp.23-32.
PARAMETERS
The MaximumRMSChange parameter is used to determine when the solution
has converged. A lower value will result in a tighter-fitting
solution, but will require more computations. Too low a value could
put the solver into an infinite loop. Values should always be less
than 1.0. A value of 0.07 is a good starting estimate.
The MaximumIterations parameter can be used to halt the solution after
a specified number of iterations.
INPUT
The input is an N-dimensional image of any type. It is assumed to be a
binary image. The filter will use an isosurface value that is halfway
between the min and max values in the image. A signed data type is not
necessary for the input.
OUTPUT
The filter will output a level set image of real, signed values. The
zero crossings of this (N-dimensional) image represent the position of
the isosurface value of interest. Values outside the zero level set
are negative and values inside the zero level set are positive values.
IMPORTANT!
The output image type you use to instantiate this filter should be a
real valued scalar type. In other words: doubles or floats.
USING THIS FILTER
The filter is relatively straightforward to use. Tests and examples
exist to illustrate. The important thing is to understand the input
and output types so you can properly interpret your results.
In the common case, the only parameter that will need to be set is the
MaximumRMSChange parameter, which determines when the solver halts.
See:
AntiAliasBinary for the procedural interface
itk::AntiAliasBinaryImageFilter for the Doxygen on the original ITK class.
AntiAliasBinaryImageFilter}
%C++ includes: sitkAntiAliasBinaryImageFilter.h
\section{Methods}{
\describe{
\item{ AntiAliasBinaryImageFilter():}{
Default Constructor that takes no arguments and initializes default
parameters
}
\item{Image Execute(const Image &image1):}{}
\item{Image Execute(Image &&image1):}{
Execute the filter on the input image
}
\item{uint32_t GetElapsedIterations() const:}{
Number of iterations run.
This is a measurement. Its value is updated in the Execute methods, so
the value will only be valid after an execution.
}
\item{double GetMaximumRMSError() const:}{}
\item{std::string GetName() const:}{
Name of this class
}
\item{uint32_t GetNumberOfIterations() const:}{}
\item{double GetRMSChange() const:}{
The Root Mean Square of the levelset upon termination.
This is a measurement. Its value is updated in the Execute methods, so
the value will only be valid after an execution.
}
\item{Self SetMaximumRMSError(double MaximumRMSError):}{}
\item{Self SetNumberOfIterations(uint32_t NumberOfIterations):}{}
\item{std::string ToString() const:}{
Print ourselves out
}
\item{ ~AntiAliasBinaryImageFilter():}{
Destructor
}
}
}
